:mod:`art.attacks.evasion`
==========================
.. automodule:: art.attacks.evasion

Adversarial Patch
-----------------
.. autoclass:: AdversarialPatch
   :members:
   :special-members:

Decision-Based Attack
---------------------
.. autoclass:: BoundaryAttack
   :members:
   :special-members:

Carlini and Wagner L_2 Attack
-----------------------------
.. autoclass:: CarliniL2Method
   :members:
   :special-members:

Carlini and Wagner L_inf Attack
-------------------------------
.. autoclass:: CarliniLInfMethod
   :members:
   :special-members:

DeepFool
--------
.. autoclass:: DeepFool
   :members:
   :special-members:

Elastic Net Attack (EAD)
------------------------
.. autoclass:: ElasticNet
   :members:
   :special-members:

Fast Gradient Method (FGM)
--------------------------
.. autoclass:: FastGradientMethod
   :members:
   :special-members:

Basic Iterative Method (BIM)
----------------------------
.. autoclass:: BasicIterativeMethod
   :members:
   :special-members:

Projected Gradient Descent (PGD)
--------------------------------
.. autoclass:: ProjectedGradientDescent
   :members:
   :special-members:

Jacobian Saliency Map Attack (JSMA)
-----------------------------------
.. autoclass:: SaliencyMapMethod
   :members:
   :special-members:

NewtonFool
----------
.. autoclass:: NewtonFool
   :members:
   :special-members:

PixelAttack
-----------
.. autoclass:: PixelAttack
   :members:
   :special-members:

ThresholdAttack
---------------
.. autoclass:: ThresholdAttack
   :members:
   :special-members:

Spatial Transformations Attack
------------------------------
.. autoclass:: SpatialTransformation
   :members:
   :special-members:

Universal Perturbation Attack
-----------------------------
.. autoclass:: UniversalPerturbation
   :members:
   :special-members:

Virtual Adversarial Method
--------------------------
.. autoclass:: VirtualAdversarialMethod
   :members:
   :special-members:

Zeroth-Order Optimization Attack (ZOO)
--------------------------------------
.. autoclass:: ZooAttack
   :members:
   :special-members:

HopSkipJump Attack
------------------
.. autoclass:: HopSkipJump
   :members:
   :special-members:

Decision Tree Attack
--------------------
.. autoclass:: DecisionTreeAttack
   :members:
   :special-members:

High Confidence Low Uncertainty Attack
--------------------------------------
.. autoclass:: HighConfidenceLowUncertainty
   :members:
   :special-members:
